/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#define glActiveShaderProgram wrap_glActiveShaderProgram
#define glActiveShaderProgramEXT wrap_glActiveShaderProgramEXT
#define glActiveTexture wrap_glActiveTexture
#define glAlphaFunc wrap_glAlphaFunc
#define glAlphaFuncQCOM wrap_glAlphaFuncQCOM
#define glAlphaFuncx wrap_glAlphaFuncx
#define glAlphaFuncxOES wrap_glAlphaFuncxOES
#define glApplyFramebufferAttachmentCMAAINTEL wrap_glApplyFramebufferAttachmentCMAAINTEL
#define glAttachShader wrap_glAttachShader
#define glBeginConditionalRenderNV wrap_glBeginConditionalRenderNV
#define glBeginPerfMonitorAMD wrap_glBeginPerfMonitorAMD
#define glBeginPerfQueryINTEL wrap_glBeginPerfQueryINTEL
#define glBeginQuery wrap_glBeginQuery
#define glBeginQueryEXT wrap_glBeginQueryEXT
#define glBeginTransformFeedback wrap_glBeginTransformFeedback
#define glBindAttribLocation wrap_glBindAttribLocation
#define glBindBuffer wrap_glBindBuffer
#define glBindBufferBase wrap_glBindBufferBase
#define glBindBufferRange wrap_glBindBufferRange
#define glBindFragDataLocationEXT wrap_glBindFragDataLocationEXT
#define glBindFragDataLocationIndexedEXT wrap_glBindFragDataLocationIndexedEXT
#define glBindFramebuffer wrap_glBindFramebuffer
#define glBindFramebufferOES wrap_glBindFramebufferOES
#define glBindImageTexture wrap_glBindImageTexture
#define glBindProgramPipeline wrap_glBindProgramPipeline
#define glBindProgramPipelineEXT wrap_glBindProgramPipelineEXT
#define glBindRenderbuffer wrap_glBindRenderbuffer
#define glBindRenderbufferOES wrap_glBindRenderbufferOES
#define glBindSampler wrap_glBindSampler
#define glBindTexture wrap_glBindTexture
#define glBindTransformFeedback wrap_glBindTransformFeedback
#define glBindVertexArray wrap_glBindVertexArray
#define glBindVertexArrayOES wrap_glBindVertexArrayOES
#define glBindVertexBuffer wrap_glBindVertexBuffer
#define glBlendBarrier wrap_glBlendBarrier
#define glBlendBarrierKHR wrap_glBlendBarrierKHR
#define glBlendBarrierNV wrap_glBlendBarrierNV
#define glBlendColor wrap_glBlendColor
#define glBlendEquation wrap_glBlendEquation
#define glBlendEquationOES wrap_glBlendEquationOES
#define glBlendEquationSeparate wrap_glBlendEquationSeparate
#define glBlendEquationSeparateOES wrap_glBlendEquationSeparateOES
#define glBlendEquationSeparatei wrap_glBlendEquationSeparatei
#define glBlendEquationSeparateiEXT wrap_glBlendEquationSeparateiEXT
#define glBlendEquationSeparateiOES wrap_glBlendEquationSeparateiOES
#define glBlendEquationi wrap_glBlendEquationi
#define glBlendEquationiEXT wrap_glBlendEquationiEXT
#define glBlendEquationiOES wrap_glBlendEquationiOES
#define glBlendFunc wrap_glBlendFunc
#define glBlendFuncSeparate wrap_glBlendFuncSeparate
#define glBlendFuncSeparateOES wrap_glBlendFuncSeparateOES
#define glBlendFuncSeparatei wrap_glBlendFuncSeparatei
#define glBlendFuncSeparateiEXT wrap_glBlendFuncSeparateiEXT
#define glBlendFuncSeparateiOES wrap_glBlendFuncSeparateiOES
#define glBlendFunci wrap_glBlendFunci
#define glBlendFunciEXT wrap_glBlendFunciEXT
#define glBlendFunciOES wrap_glBlendFunciOES
#define glBlendParameteriNV wrap_glBlendParameteriNV
#define glBlitFramebuffer wrap_glBlitFramebuffer
#define glBlitFramebufferANGLE wrap_glBlitFramebufferANGLE
#define glBlitFramebufferNV wrap_glBlitFramebufferNV
#define glBufferData wrap_glBufferData
#define glBufferStorageEXT wrap_glBufferStorageEXT
#define glBufferSubData wrap_glBufferSubData
#define glCheckFramebufferStatus wrap_glCheckFramebufferStatus
#define glCheckFramebufferStatusOES wrap_glCheckFramebufferStatusOES
#define glClear wrap_glClear
#define glClearBufferfi wrap_glClearBufferfi
#define glClearBufferfv wrap_glClearBufferfv
#define glClearBufferiv wrap_glClearBufferiv
#define glClearBufferuiv wrap_glClearBufferuiv
#define glClearColor wrap_glClearColor
#define glClearColorx wrap_glClearColorx
#define glClearColorxOES wrap_glClearColorxOES
#define glClearDepthf wrap_glClearDepthf
#define glClearDepthfOES wrap_glClearDepthfOES
#define glClearDepthx wrap_glClearDepthx
#define glClearDepthxOES wrap_glClearDepthxOES
#define glClearStencil wrap_glClearStencil
#define glClientActiveTexture wrap_glClientActiveTexture
#define glClientWaitSync wrap_glClientWaitSync
#define glClientWaitSyncAPPLE wrap_glClientWaitSyncAPPLE
#define glClipPlanef wrap_glClipPlanef
#define glClipPlanefIMG wrap_glClipPlanefIMG
#define glClipPlanefOES wrap_glClipPlanefOES
#define glClipPlanex wrap_glClipPlanex
#define glClipPlanexIMG wrap_glClipPlanexIMG
#define glClipPlanexOES wrap_glClipPlanexOES
#define glColor4f wrap_glColor4f
#define glColor4ub wrap_glColor4ub
#define glColor4x wrap_glColor4x
#define glColor4xOES wrap_glColor4xOES
#define glColorMask wrap_glColorMask
#define glColorMaski wrap_glColorMaski
#define glColorMaskiEXT wrap_glColorMaskiEXT
#define glColorMaskiOES wrap_glColorMaskiOES
#define glColorPointer wrap_glColorPointer
#define glCompileShader wrap_glCompileShader
#define glCompressedTexImage2D wrap_glCompressedTexImage2D
#define glCompressedTexImage3D wrap_glCompressedTexImage3D
#define glCompressedTexImage3DOES wrap_glCompressedTexImage3DOES
#define glCompressedTexSubImage2D wrap_glCompressedTexSubImage2D
#define glCompressedTexSubImage3D wrap_glCompressedTexSubImage3D
#define glCompressedTexSubImage3DOES wrap_glCompressedTexSubImage3DOES
#define glCopyBufferSubData wrap_glCopyBufferSubData
#define glCopyBufferSubDataNV wrap_glCopyBufferSubDataNV
#define glCopyImageSubData wrap_glCopyImageSubData
#define glCopyImageSubDataEXT wrap_glCopyImageSubDataEXT
#define glCopyImageSubDataOES wrap_glCopyImageSubDataOES
#define glCopyPathNV wrap_glCopyPathNV
#define glCopyTexImage2D wrap_glCopyTexImage2D
#define glCopyTexSubImage2D wrap_glCopyTexSubImage2D
#define glCopyTexSubImage3D wrap_glCopyTexSubImage3D
#define glCopyTexSubImage3DOES wrap_glCopyTexSubImage3DOES
#define glCopyTextureLevelsAPPLE wrap_glCopyTextureLevelsAPPLE
#define glCoverFillPathInstancedNV wrap_glCoverFillPathInstancedNV
#define glCoverFillPathNV wrap_glCoverFillPathNV
#define glCoverStrokePathInstancedNV wrap_glCoverStrokePathInstancedNV
#define glCoverStrokePathNV wrap_glCoverStrokePathNV
#define glCoverageMaskNV wrap_glCoverageMaskNV
#define glCoverageModulationNV wrap_glCoverageModulationNV
#define glCoverageModulationTableNV wrap_glCoverageModulationTableNV
#define glCoverageOperationNV wrap_glCoverageOperationNV
#define glCreatePerfQueryINTEL wrap_glCreatePerfQueryINTEL
#define glCreateProgram wrap_glCreateProgram
#define glCreateShader wrap_glCreateShader
#define glCreateShaderProgramv wrap_glCreateShaderProgramv
#define glCreateShaderProgramvEXT wrap_glCreateShaderProgramvEXT
#define glCullFace wrap_glCullFace
#define glCurrentPaletteMatrixOES wrap_glCurrentPaletteMatrixOES
#define glDebugMessageCallback wrap_glDebugMessageCallback
#define glDebugMessageCallbackKHR wrap_glDebugMessageCallbackKHR
#define glDebugMessageControl wrap_glDebugMessageControl
#define glDebugMessageControlKHR wrap_glDebugMessageControlKHR
#define glDebugMessageInsert wrap_glDebugMessageInsert
#define glDebugMessageInsertKHR wrap_glDebugMessageInsertKHR
#define glDeleteBuffers wrap_glDeleteBuffers
#define glDeleteFencesNV wrap_glDeleteFencesNV
#define glDeleteFramebuffers wrap_glDeleteFramebuffers
#define glDeleteFramebuffersOES wrap_glDeleteFramebuffersOES
#define glDeletePathsNV wrap_glDeletePathsNV
#define glDeletePerfMonitorsAMD wrap_glDeletePerfMonitorsAMD
#define glDeletePerfQueryINTEL wrap_glDeletePerfQueryINTEL
#define glDeleteProgram wrap_glDeleteProgram
#define glDeleteProgramPipelines wrap_glDeleteProgramPipelines
#define glDeleteProgramPipelinesEXT wrap_glDeleteProgramPipelinesEXT
#define glDeleteQueries wrap_glDeleteQueries
#define glDeleteQueriesEXT wrap_glDeleteQueriesEXT
#define glDeleteRenderbuffers wrap_glDeleteRenderbuffers
#define glDeleteRenderbuffersOES wrap_glDeleteRenderbuffersOES
#define glDeleteSamplers wrap_glDeleteSamplers
#define glDeleteShader wrap_glDeleteShader
#define glDeleteSync wrap_glDeleteSync
#define glDeleteSyncAPPLE wrap_glDeleteSyncAPPLE
#define glDeleteTextures wrap_glDeleteTextures
#define glDeleteTransformFeedbacks wrap_glDeleteTransformFeedbacks
#define glDeleteVertexArrays wrap_glDeleteVertexArrays
#define glDeleteVertexArraysOES wrap_glDeleteVertexArraysOES
#define glDepthFunc wrap_glDepthFunc
#define glDepthMask wrap_glDepthMask
#define glDepthRangeArrayfvNV wrap_glDepthRangeArrayfvNV
#define glDepthRangeIndexedfNV wrap_glDepthRangeIndexedfNV
#define glDepthRangef wrap_glDepthRangef
#define glDepthRangefOES wrap_glDepthRangefOES
#define glDepthRangex wrap_glDepthRangex
#define glDepthRangexOES wrap_glDepthRangexOES
#define glDetachShader wrap_glDetachShader
#define glDisable wrap_glDisable
#define glDisableClientState wrap_glDisableClientState
#define glDisableDriverControlQCOM wrap_glDisableDriverControlQCOM
#define glDisableVertexAttribArray wrap_glDisableVertexAttribArray
#define glDisablei wrap_glDisablei
#define glDisableiEXT wrap_glDisableiEXT
#define glDisableiNV wrap_glDisableiNV
#define glDisableiOES wrap_glDisableiOES
#define glDiscardFramebufferEXT wrap_glDiscardFramebufferEXT
#define glDispatchCompute wrap_glDispatchCompute
#define glDispatchComputeIndirect wrap_glDispatchComputeIndirect
#define glDrawArrays wrap_glDrawArrays
#define glDrawArraysIndirect wrap_glDrawArraysIndirect
#define glDrawArraysInstanced wrap_glDrawArraysInstanced
#define glDrawArraysInstancedANGLE wrap_glDrawArraysInstancedANGLE
#define glDrawArraysInstancedBaseInstanceEXT wrap_glDrawArraysInstancedBaseInstanceEXT
#define glDrawArraysInstancedEXT wrap_glDrawArraysInstancedEXT
#define glDrawArraysInstancedNV wrap_glDrawArraysInstancedNV
#define glDrawBuffers wrap_glDrawBuffers
#define glDrawBuffersEXT wrap_glDrawBuffersEXT
#define glDrawBuffersIndexedEXT wrap_glDrawBuffersIndexedEXT
#define glDrawBuffersNV wrap_glDrawBuffersNV
#define glDrawElements wrap_glDrawElements
#define glDrawElementsBaseVertex wrap_glDrawElementsBaseVertex
#define glDrawElementsBaseVertexEXT wrap_glDrawElementsBaseVertexEXT
#define glDrawElementsBaseVertexOES wrap_glDrawElementsBaseVertexOES
#define glDrawElementsIndirect wrap_glDrawElementsIndirect
#define glDrawElementsInstanced wrap_glDrawElementsInstanced
#define glDrawElementsInstancedANGLE wrap_glDrawElementsInstancedANGLE
#define glDrawElementsInstancedBaseInstanceEXT wrap_glDrawElementsInstancedBaseInstanceEXT
#define glDrawElementsInstancedBaseVertex wrap_glDrawElementsInstancedBaseVertex
#define glDrawElementsInstancedBaseVertexBaseInstanceEXT \
    wrap_glDrawElementsInstancedBaseVertexBaseInstanceEXT
#define glDrawElementsInstancedBaseVertexEXT wrap_glDrawElementsInstancedBaseVertexEXT
#define glDrawElementsInstancedBaseVertexOES wrap_glDrawElementsInstancedBaseVertexOES
#define glDrawElementsInstancedEXT wrap_glDrawElementsInstancedEXT
#define glDrawElementsInstancedNV wrap_glDrawElementsInstancedNV
#define glDrawRangeElements wrap_glDrawRangeElements
#define glDrawRangeElementsBaseVertex wrap_glDrawRangeElementsBaseVertex
#define glDrawRangeElementsBaseVertexEXT wrap_glDrawRangeElementsBaseVertexEXT
#define glDrawRangeElementsBaseVertexOES wrap_glDrawRangeElementsBaseVertexOES
#define glDrawTexfOES wrap_glDrawTexfOES
#define glDrawTexfvOES wrap_glDrawTexfvOES
#define glDrawTexiOES wrap_glDrawTexiOES
#define glDrawTexivOES wrap_glDrawTexivOES
#define glDrawTexsOES wrap_glDrawTexsOES
#define glDrawTexsvOES wrap_glDrawTexsvOES
#define glDrawTexxOES wrap_glDrawTexxOES
#define glDrawTexxvOES wrap_glDrawTexxvOES
#define glEGLImageTargetRenderbufferStorageOES wrap_glEGLImageTargetRenderbufferStorageOES
#define glEGLImageTargetTexture2DOES wrap_glEGLImageTargetTexture2DOES
#define glEnable wrap_glEnable
#define glEnableClientState wrap_glEnableClientState
#define glEnableDriverControlQCOM wrap_glEnableDriverControlQCOM
#define glEnableVertexAttribArray wrap_glEnableVertexAttribArray
#define glEnablei wrap_glEnablei
#define glEnableiEXT wrap_glEnableiEXT
#define glEnableiNV wrap_glEnableiNV
#define glEnableiOES wrap_glEnableiOES
#define glEndConditionalRenderNV wrap_glEndConditionalRenderNV
#define glEndPerfMonitorAMD wrap_glEndPerfMonitorAMD
#define glEndPerfQueryINTEL wrap_glEndPerfQueryINTEL
#define glEndQuery wrap_glEndQuery
#define glEndQueryEXT wrap_glEndQueryEXT
#define glEndTilingQCOM wrap_glEndTilingQCOM
#define glEndTransformFeedback wrap_glEndTransformFeedback
#define glExtGetBufferPointervQCOM wrap_glExtGetBufferPointervQCOM
#define glExtGetBuffersQCOM wrap_glExtGetBuffersQCOM
#define glExtGetFramebuffersQCOM wrap_glExtGetFramebuffersQCOM
#define glExtGetProgramBinarySourceQCOM wrap_glExtGetProgramBinarySourceQCOM
#define glExtGetProgramsQCOM wrap_glExtGetProgramsQCOM
#define glExtGetRenderbuffersQCOM wrap_glExtGetRenderbuffersQCOM
#define glExtGetShadersQCOM wrap_glExtGetShadersQCOM
#define glExtGetTexLevelParameterivQCOM wrap_glExtGetTexLevelParameterivQCOM
#define glExtGetTexSubImageQCOM wrap_glExtGetTexSubImageQCOM
#define glExtGetTexturesQCOM wrap_glExtGetTexturesQCOM
#define glExtIsProgramBinaryQCOM wrap_glExtIsProgramBinaryQCOM
#define glExtTexObjectStateOverrideiQCOM wrap_glExtTexObjectStateOverrideiQCOM
#define glFenceSync wrap_glFenceSync
#define glFenceSyncAPPLE wrap_glFenceSyncAPPLE
#define glFinish wrap_glFinish
#define glFinishFenceNV wrap_glFinishFenceNV
#define glFlush wrap_glFlush
#define glFlushMappedBufferRange wrap_glFlushMappedBufferRange
#define glFlushMappedBufferRangeEXT wrap_glFlushMappedBufferRangeEXT
#define glFogf wrap_glFogf
#define glFogfv wrap_glFogfv
#define glFogx wrap_glFogx
#define glFogxOES wrap_glFogxOES
#define glFogxv wrap_glFogxv
#define glFogxvOES wrap_glFogxvOES
#define glFragmentCoverageColorNV wrap_glFragmentCoverageColorNV
#define glFramebufferParameteri wrap_glFramebufferParameteri
#define glFramebufferRenderbuffer wrap_glFramebufferRenderbuffer
#define glFramebufferRenderbufferOES wrap_glFramebufferRenderbufferOES
#define glFramebufferSampleLocationsfvNV wrap_glFramebufferSampleLocationsfvNV
#define glFramebufferTexture wrap_glFramebufferTexture
#define glFramebufferTexture2D wrap_glFramebufferTexture2D
#define glFramebufferTexture2DMultisampleEXT wrap_glFramebufferTexture2DMultisampleEXT
#define glFramebufferTexture2DMultisampleIMG wrap_glFramebufferTexture2DMultisampleIMG
#define glFramebufferTexture2DOES wrap_glFramebufferTexture2DOES
#define glFramebufferTexture3DOES wrap_glFramebufferTexture3DOES
#define glFramebufferTextureEXT wrap_glFramebufferTextureEXT
#define glFramebufferTextureLayer wrap_glFramebufferTextureLayer
#define glFramebufferTextureMultisampleMultiviewOVR wrap_glFramebufferTextureMultisampleMultiviewOVR
#define glFramebufferTextureMultiviewOVR wrap_glFramebufferTextureMultiviewOVR
#define glFramebufferTextureOES wrap_glFramebufferTextureOES
#define glFrontFace wrap_glFrontFace
#define glFrustumf wrap_glFrustumf
#define glFrustumfOES wrap_glFrustumfOES
#define glFrustumx wrap_glFrustumx
#define glFrustumxOES wrap_glFrustumxOES
#define glGenBuffers wrap_glGenBuffers
#define glGenFencesNV wrap_glGenFencesNV
#define glGenFramebuffers wrap_glGenFramebuffers
#define glGenFramebuffersOES wrap_glGenFramebuffersOES
#define glGenPathsNV wrap_glGenPathsNV
#define glGenPerfMonitorsAMD wrap_glGenPerfMonitorsAMD
#define glGenProgramPipelines wrap_glGenProgramPipelines
#define glGenProgramPipelinesEXT wrap_glGenProgramPipelinesEXT
#define glGenQueries wrap_glGenQueries
#define glGenQueriesEXT wrap_glGenQueriesEXT
#define glGenRenderbuffers wrap_glGenRenderbuffers
#define glGenRenderbuffersOES wrap_glGenRenderbuffersOES
#define glGenSamplers wrap_glGenSamplers
#define glGenTextures wrap_glGenTextures
#define glGenTransformFeedbacks wrap_glGenTransformFeedbacks
#define glGenVertexArrays wrap_glGenVertexArrays
#define glGenVertexArraysOES wrap_glGenVertexArraysOES
#define glGenerateMipmap wrap_glGenerateMipmap
#define glGenerateMipmapOES wrap_glGenerateMipmapOES
#define glGetActiveAttrib wrap_glGetActiveAttrib
#define glGetActiveUniform wrap_glGetActiveUniform
#define glGetActiveUniformBlockName wrap_glGetActiveUniformBlockName
#define glGetActiveUniformBlockiv wrap_glGetActiveUniformBlockiv
#define glGetActiveUniformsiv wrap_glGetActiveUniformsiv
#define glGetAttachedShaders wrap_glGetAttachedShaders
#define glGetAttribLocation wrap_glGetAttribLocation
#define glGetBooleani_v wrap_glGetBooleani_v
#define glGetBooleanv wrap_glGetBooleanv
#define glGetBufferParameteri64v wrap_glGetBufferParameteri64v
#define glGetBufferParameteriv wrap_glGetBufferParameteriv
#define glGetBufferPointerv wrap_glGetBufferPointerv
#define glGetBufferPointervOES wrap_glGetBufferPointervOES
#define glGetClipPlanef wrap_glGetClipPlanef
#define glGetClipPlanefOES wrap_glGetClipPlanefOES
#define glGetClipPlanex wrap_glGetClipPlanex
#define glGetClipPlanexOES wrap_glGetClipPlanexOES
#define glGetCoverageModulationTableNV wrap_glGetCoverageModulationTableNV
#define glGetDebugMessageLog wrap_glGetDebugMessageLog
#define glGetDebugMessageLogKHR wrap_glGetDebugMessageLogKHR
#define glGetDriverControlStringQCOM wrap_glGetDriverControlStringQCOM
#define glGetDriverControlsQCOM wrap_glGetDriverControlsQCOM
#define glGetError wrap_glGetError
#define glGetFenceivNV wrap_glGetFenceivNV
#define glGetFirstPerfQueryIdINTEL wrap_glGetFirstPerfQueryIdINTEL
#define glGetFixedv wrap_glGetFixedv
#define glGetFixedvOES wrap_glGetFixedvOES
#define glGetFloati_vNV wrap_glGetFloati_vNV
#define glGetFloatv wrap_glGetFloatv
#define glGetFragDataIndexEXT wrap_glGetFragDataIndexEXT
#define glGetFragDataLocation wrap_glGetFragDataLocation
#define glGetFramebufferAttachmentParameteriv wrap_glGetFramebufferAttachmentParameteriv
#define glGetFramebufferAttachmentParameterivOES wrap_glGetFramebufferAttachmentParameterivOES
#define glGetFramebufferParameteriv wrap_glGetFramebufferParameteriv
#define glGetGraphicsResetStatus wrap_glGetGraphicsResetStatus
#define glGetGraphicsResetStatusEXT wrap_glGetGraphicsResetStatusEXT
#define glGetGraphicsResetStatusKHR wrap_glGetGraphicsResetStatusKHR
#define glGetImageHandleNV wrap_glGetImageHandleNV
#define glGetInteger64i_v wrap_glGetInteger64i_v
#define glGetInteger64v wrap_glGetInteger64v
#define glGetInteger64vAPPLE wrap_glGetInteger64vAPPLE
#define glGetIntegeri_v wrap_glGetIntegeri_v
#define glGetIntegeri_vEXT wrap_glGetIntegeri_vEXT
#define glGetIntegerv wrap_glGetIntegerv
#define glGetInternalformatSampleivNV wrap_glGetInternalformatSampleivNV
#define glGetInternalformativ wrap_glGetInternalformativ
#define glGetLightfv wrap_glGetLightfv
#define glGetLightxv wrap_glGetLightxv
#define glGetLightxvOES wrap_glGetLightxvOES
#define glGetMaterialfv wrap_glGetMaterialfv
#define glGetMaterialxv wrap_glGetMaterialxv
#define glGetMaterialxvOES wrap_glGetMaterialxvOES
#define glGetMultisamplefv wrap_glGetMultisamplefv
#define glGetNextPerfQueryIdINTEL wrap_glGetNextPerfQueryIdINTEL
#define glGetObjectLabel wrap_glGetObjectLabel
#define glGetObjectLabelEXT wrap_glGetObjectLabelEXT
#define glGetObjectLabelKHR wrap_glGetObjectLabelKHR
#define glGetObjectPtrLabel wrap_glGetObjectPtrLabel
#define glGetObjectPtrLabelKHR wrap_glGetObjectPtrLabelKHR
#define glGetPathCommandsNV wrap_glGetPathCommandsNV
#define glGetPathCoordsNV wrap_glGetPathCoordsNV
#define glGetPathDashArrayNV wrap_glGetPathDashArrayNV
#define glGetPathLengthNV wrap_glGetPathLengthNV
#define glGetPathMetricRangeNV wrap_glGetPathMetricRangeNV
#define glGetPathMetricsNV wrap_glGetPathMetricsNV
#define glGetPathParameterfvNV wrap_glGetPathParameterfvNV
#define glGetPathParameterivNV wrap_glGetPathParameterivNV
#define glGetPathSpacingNV wrap_glGetPathSpacingNV
#define glGetPerfCounterInfoINTEL wrap_glGetPerfCounterInfoINTEL
#define glGetPerfMonitorCounterDataAMD wrap_glGetPerfMonitorCounterDataAMD
#define glGetPerfMonitorCounterInfoAMD wrap_glGetPerfMonitorCounterInfoAMD
#define glGetPerfMonitorCounterStringAMD wrap_glGetPerfMonitorCounterStringAMD
#define glGetPerfMonitorCountersAMD wrap_glGetPerfMonitorCountersAMD
#define glGetPerfMonitorGroupStringAMD wrap_glGetPerfMonitorGroupStringAMD
#define glGetPerfMonitorGroupsAMD wrap_glGetPerfMonitorGroupsAMD
#define glGetPerfQueryDataINTEL wrap_glGetPerfQueryDataINTEL
#define glGetPerfQueryIdByNameINTEL wrap_glGetPerfQueryIdByNameINTEL
#define glGetPerfQueryInfoINTEL wrap_glGetPerfQueryInfoINTEL
#define glGetPointerv wrap_glGetPointerv
#define glGetPointervKHR wrap_glGetPointervKHR
#define glGetProgramBinary wrap_glGetProgramBinary
#define glGetProgramBinaryOES wrap_glGetProgramBinaryOES
#define glGetProgramInfoLog wrap_glGetProgramInfoLog
#define glGetProgramInterfaceiv wrap_glGetProgramInterfaceiv
#define glGetProgramPipelineInfoLog wrap_glGetProgramPipelineInfoLog
#define glGetProgramPipelineInfoLogEXT wrap_glGetProgramPipelineInfoLogEXT
#define glGetProgramPipelineiv wrap_glGetProgramPipelineiv
#define glGetProgramPipelineivEXT wrap_glGetProgramPipelineivEXT
#define glGetProgramResourceIndex wrap_glGetProgramResourceIndex
#define glGetProgramResourceLocation wrap_glGetProgramResourceLocation
#define glGetProgramResourceLocationIndexEXT wrap_glGetProgramResourceLocationIndexEXT
#define glGetProgramResourceName wrap_glGetProgramResourceName
#define glGetProgramResourcefvNV wrap_glGetProgramResourcefvNV
#define glGetProgramResourceiv wrap_glGetProgramResourceiv
#define glGetProgramiv wrap_glGetProgramiv
#define glGetQueryObjecti64vEXT wrap_glGetQueryObjecti64vEXT
#define glGetQueryObjectivEXT wrap_glGetQueryObjectivEXT
#define glGetQueryObjectui64vEXT wrap_glGetQueryObjectui64vEXT
#define glGetQueryObjectuiv wrap_glGetQueryObjectuiv
#define glGetQueryObjectuivEXT wrap_glGetQueryObjectuivEXT
#define glGetQueryiv wrap_glGetQueryiv
#define glGetQueryivEXT wrap_glGetQueryivEXT
#define glGetRenderbufferParameteriv wrap_glGetRenderbufferParameteriv
#define glGetRenderbufferParameterivOES wrap_glGetRenderbufferParameterivOES
#define glGetSamplerParameterIiv wrap_glGetSamplerParameterIiv
#define glGetSamplerParameterIivEXT wrap_glGetSamplerParameterIivEXT
#define glGetSamplerParameterIivOES wrap_glGetSamplerParameterIivOES
#define glGetSamplerParameterIuiv wrap_glGetSamplerParameterIuiv
#define glGetSamplerParameterIuivEXT wrap_glGetSamplerParameterIuivEXT
#define glGetSamplerParameterIuivOES wrap_glGetSamplerParameterIuivOES
#define glGetSamplerParameterfv wrap_glGetSamplerParameterfv
#define glGetSamplerParameteriv wrap_glGetSamplerParameteriv
#define glGetShaderInfoLog wrap_glGetShaderInfoLog
#define glGetShaderPrecisionFormat wrap_glGetShaderPrecisionFormat
#define glGetShaderSource wrap_glGetShaderSource
#define glGetShaderiv wrap_glGetShaderiv
#define glGetString wrap_glGetString
#define glGetStringi wrap_glGetStringi
#define glGetSynciv wrap_glGetSynciv
#define glGetSyncivAPPLE wrap_glGetSyncivAPPLE
#define glGetTexEnvfv wrap_glGetTexEnvfv
#define glGetTexEnviv wrap_glGetTexEnviv
#define glGetTexEnvxv wrap_glGetTexEnvxv
#define glGetTexEnvxvOES wrap_glGetTexEnvxvOES
#define glGetTexGenfvOES wrap_glGetTexGenfvOES
#define glGetTexGenivOES wrap_glGetTexGenivOES
#define glGetTexGenxvOES wrap_glGetTexGenxvOES
#define glGetTexLevelParameterfv wrap_glGetTexLevelParameterfv
#define glGetTexLevelParameteriv wrap_glGetTexLevelParameteriv
#define glGetTexParameterIiv wrap_glGetTexParameterIiv
#define glGetTexParameterIivEXT wrap_glGetTexParameterIivEXT
#define glGetTexParameterIivOES wrap_glGetTexParameterIivOES
#define glGetTexParameterIuiv wrap_glGetTexParameterIuiv
#define glGetTexParameterIuivEXT wrap_glGetTexParameterIuivEXT
#define glGetTexParameterIuivOES wrap_glGetTexParameterIuivOES
#define glGetTexParameterfv wrap_glGetTexParameterfv
#define glGetTexParameteriv wrap_glGetTexParameteriv
#define glGetTexParameterxv wrap_glGetTexParameterxv
#define glGetTexParameterxvOES wrap_glGetTexParameterxvOES
#define glGetTextureHandleNV wrap_glGetTextureHandleNV
#define glGetTextureSamplerHandleNV wrap_glGetTextureSamplerHandleNV
#define glGetTransformFeedbackVarying wrap_glGetTransformFeedbackVarying
#define glGetTranslatedShaderSourceANGLE wrap_glGetTranslatedShaderSourceANGLE
#define glGetUniformBlockIndex wrap_glGetUniformBlockIndex
#define glGetUniformIndices wrap_glGetUniformIndices
#define glGetUniformLocation wrap_glGetUniformLocation
#define glGetUniformfv wrap_glGetUniformfv
#define glGetUniformiv wrap_glGetUniformiv
#define glGetUniformuiv wrap_glGetUniformuiv
#define glGetVertexAttribIiv wrap_glGetVertexAttribIiv
#define glGetVertexAttribIuiv wrap_glGetVertexAttribIuiv
#define glGetVertexAttribPointerv wrap_glGetVertexAttribPointerv
#define glGetVertexAttribfv wrap_glGetVertexAttribfv
#define glGetVertexAttribiv wrap_glGetVertexAttribiv
#define glGetnUniformfv wrap_glGetnUniformfv
#define glGetnUniformfvEXT wrap_glGetnUniformfvEXT
#define glGetnUniformfvKHR wrap_glGetnUniformfvKHR
#define glGetnUniformiv wrap_glGetnUniformiv
#define glGetnUniformivEXT wrap_glGetnUniformivEXT
#define glGetnUniformivKHR wrap_glGetnUniformivKHR
#define glGetnUniformuiv wrap_glGetnUniformuiv
#define glGetnUniformuivKHR wrap_glGetnUniformuivKHR
#define glHint wrap_glHint
#define glInsertEventMarkerEXT wrap_glInsertEventMarkerEXT
#define glInterpolatePathsNV wrap_glInterpolatePathsNV
#define glInvalidateFramebuffer wrap_glInvalidateFramebuffer
#define glInvalidateSubFramebuffer wrap_glInvalidateSubFramebuffer
#define glIsBuffer wrap_glIsBuffer
#define glIsEnabled wrap_glIsEnabled
#define glIsEnabledi wrap_glIsEnabledi
#define glIsEnablediEXT wrap_glIsEnablediEXT
#define glIsEnablediNV wrap_glIsEnablediNV
#define glIsEnablediOES wrap_glIsEnablediOES
#define glIsFenceNV wrap_glIsFenceNV
#define glIsFramebuffer wrap_glIsFramebuffer
#define glIsFramebufferOES wrap_glIsFramebufferOES
#define glIsImageHandleResidentNV wrap_glIsImageHandleResidentNV
#define glIsPathNV wrap_glIsPathNV
#define glIsPointInFillPathNV wrap_glIsPointInFillPathNV
#define glIsPointInStrokePathNV wrap_glIsPointInStrokePathNV
#define glIsProgram wrap_glIsProgram
#define glIsProgramPipeline wrap_glIsProgramPipeline
#define glIsProgramPipelineEXT wrap_glIsProgramPipelineEXT
#define glIsQuery wrap_glIsQuery
#define glIsQueryEXT wrap_glIsQueryEXT
#define glIsRenderbuffer wrap_glIsRenderbuffer
#define glIsRenderbufferOES wrap_glIsRenderbufferOES
#define glIsSampler wrap_glIsSampler
#define glIsShader wrap_glIsShader
#define glIsSync wrap_glIsSync
#define glIsSyncAPPLE wrap_glIsSyncAPPLE
#define glIsTexture wrap_glIsTexture
#define glIsTextureHandleResidentNV wrap_glIsTextureHandleResidentNV
#define glIsTransformFeedback wrap_glIsTransformFeedback
#define glIsVertexArray wrap_glIsVertexArray
#define glIsVertexArrayOES wrap_glIsVertexArrayOES
#define glLabelObjectEXT wrap_glLabelObjectEXT
#define glLightModelf wrap_glLightModelf
#define glLightModelfv wrap_glLightModelfv
#define glLightModelx wrap_glLightModelx
#define glLightModelxOES wrap_glLightModelxOES
#define glLightModelxv wrap_glLightModelxv
#define glLightModelxvOES wrap_glLightModelxvOES
#define glLightf wrap_glLightf
#define glLightfv wrap_glLightfv
#define glLightx wrap_glLightx
#define glLightxOES wrap_glLightxOES
#define glLightxv wrap_glLightxv
#define glLightxvOES wrap_glLightxvOES
#define glLineWidth wrap_glLineWidth
#define glLineWidthx wrap_glLineWidthx
#define glLineWidthxOES wrap_glLineWidthxOES
#define glLinkProgram wrap_glLinkProgram
#define glLoadIdentity wrap_glLoadIdentity
#define glLoadMatrixf wrap_glLoadMatrixf
#define glLoadMatrixx wrap_glLoadMatrixx
#define glLoadMatrixxOES wrap_glLoadMatrixxOES
#define glLoadPaletteFromModelViewMatrixOES wrap_glLoadPaletteFromModelViewMatrixOES
#define glLogicOp wrap_glLogicOp
#define glMakeImageHandleNonResidentNV wrap_glMakeImageHandleNonResidentNV
#define glMakeImageHandleResidentNV wrap_glMakeImageHandleResidentNV
#define glMakeTextureHandleNonResidentNV wrap_glMakeTextureHandleNonResidentNV
#define glMakeTextureHandleResidentNV wrap_glMakeTextureHandleResidentNV
#define glMapBufferOES wrap_glMapBufferOES
#define glMapBufferRange wrap_glMapBufferRange
#define glMapBufferRangeEXT wrap_glMapBufferRangeEXT
#define glMaterialf wrap_glMaterialf
#define glMaterialfv wrap_glMaterialfv
#define glMaterialx wrap_glMaterialx
#define glMaterialxOES wrap_glMaterialxOES
#define glMaterialxv wrap_glMaterialxv
#define glMaterialxvOES wrap_glMaterialxvOES
#define glMatrixIndexPointerOES wrap_glMatrixIndexPointerOES
#define glMatrixLoad3x2fNV wrap_glMatrixLoad3x2fNV
#define glMatrixLoad3x3fNV wrap_glMatrixLoad3x3fNV
#define glMatrixLoadTranspose3x3fNV wrap_glMatrixLoadTranspose3x3fNV
#define glMatrixMode wrap_glMatrixMode
#define glMatrixMult3x2fNV wrap_glMatrixMult3x2fNV
#define glMatrixMult3x3fNV wrap_glMatrixMult3x3fNV
#define glMatrixMultTranspose3x3fNV wrap_glMatrixMultTranspose3x3fNV
#define glMemoryBarrier wrap_glMemoryBarrier
#define glMemoryBarrierByRegion wrap_glMemoryBarrierByRegion
#define glMinSampleShading wrap_glMinSampleShading
#define glMinSampleShadingOES wrap_glMinSampleShadingOES
#define glMultMatrixf wrap_glMultMatrixf
#define glMultMatrixx wrap_glMultMatrixx
#define glMultMatrixxOES wrap_glMultMatrixxOES
#define glMultiDrawArraysEXT wrap_glMultiDrawArraysEXT
#define glMultiDrawArraysIndirectEXT wrap_glMultiDrawArraysIndirectEXT
#define glMultiDrawElementsBaseVertexEXT wrap_glMultiDrawElementsBaseVertexEXT
#define glMultiDrawElementsBaseVertexOES wrap_glMultiDrawElementsBaseVertexOES
#define glMultiDrawElementsEXT wrap_glMultiDrawElementsEXT
#define glMultiDrawElementsIndirectEXT wrap_glMultiDrawElementsIndirectEXT
#define glMultiTexCoord4f wrap_glMultiTexCoord4f
#define glMultiTexCoord4x wrap_glMultiTexCoord4x
#define glMultiTexCoord4xOES wrap_glMultiTexCoord4xOES
#define glNamedFramebufferSampleLocationsfvNV wrap_glNamedFramebufferSampleLocationsfvNV
#define glNormal3f wrap_glNormal3f
#define glNormal3x wrap_glNormal3x
#define glNormal3xOES wrap_glNormal3xOES
#define glNormalPointer wrap_glNormalPointer
#define glObjectLabel wrap_glObjectLabel
#define glObjectLabelKHR wrap_glObjectLabelKHR
#define glObjectPtrLabel wrap_glObjectPtrLabel
#define glObjectPtrLabelKHR wrap_glObjectPtrLabelKHR
#define glOrthof wrap_glOrthof
#define glOrthofOES wrap_glOrthofOES
#define glOrthox wrap_glOrthox
#define glOrthoxOES wrap_glOrthoxOES
#define glPatchParameteri wrap_glPatchParameteri
#define glPatchParameteriEXT wrap_glPatchParameteriEXT
#define glPatchParameteriOES wrap_glPatchParameteriOES
#define glPathCommandsNV wrap_glPathCommandsNV
#define glPathCoordsNV wrap_glPathCoordsNV
#define glPathCoverDepthFuncNV wrap_glPathCoverDepthFuncNV
#define glPathDashArrayNV wrap_glPathDashArrayNV
#define glPathGlyphIndexArrayNV wrap_glPathGlyphIndexArrayNV
#define glPathGlyphIndexRangeNV wrap_glPathGlyphIndexRangeNV
#define glPathGlyphRangeNV wrap_glPathGlyphRangeNV
#define glPathGlyphsNV wrap_glPathGlyphsNV
#define glPathMemoryGlyphIndexArrayNV wrap_glPathMemoryGlyphIndexArrayNV
#define glPathParameterfNV wrap_glPathParameterfNV
#define glPathParameterfvNV wrap_glPathParameterfvNV
#define glPathParameteriNV wrap_glPathParameteriNV
#define glPathParameterivNV wrap_glPathParameterivNV
#define glPathStencilDepthOffsetNV wrap_glPathStencilDepthOffsetNV
#define glPathStencilFuncNV wrap_glPathStencilFuncNV
#define glPathStringNV wrap_glPathStringNV
#define glPathSubCommandsNV wrap_glPathSubCommandsNV
#define glPathSubCoordsNV wrap_glPathSubCoordsNV
#define glPauseTransformFeedback wrap_glPauseTransformFeedback
#define glPixelStorei wrap_glPixelStorei
#define glPointAlongPathNV wrap_glPointAlongPathNV
#define glPointParameterf wrap_glPointParameterf
#define glPointParameterfv wrap_glPointParameterfv
#define glPointParameterx wrap_glPointParameterx
#define glPointParameterxOES wrap_glPointParameterxOES
#define glPointParameterxv wrap_glPointParameterxv
#define glPointParameterxvOES wrap_glPointParameterxvOES
#define glPointSize wrap_glPointSize
#define glPointSizePointerOES wrap_glPointSizePointerOES
#define glPointSizex wrap_glPointSizex
#define glPointSizexOES wrap_glPointSizexOES
#define glPolygonModeNV wrap_glPolygonModeNV
#define glPolygonOffset wrap_glPolygonOffset
#define glPolygonOffsetx wrap_glPolygonOffsetx
#define glPolygonOffsetxOES wrap_glPolygonOffsetxOES
#define glPopDebugGroup wrap_glPopDebugGroup
#define glPopDebugGroupKHR wrap_glPopDebugGroupKHR
#define glPopGroupMarkerEXT wrap_glPopGroupMarkerEXT
#define glPopMatrix wrap_glPopMatrix
#define glPrimitiveBoundingBox wrap_glPrimitiveBoundingBox
#define glPrimitiveBoundingBoxEXT wrap_glPrimitiveBoundingBoxEXT
#define glPrimitiveBoundingBoxOES wrap_glPrimitiveBoundingBoxOES
#define glProgramBinary wrap_glProgramBinary
#define glProgramBinaryOES wrap_glProgramBinaryOES
#define glProgramParameteri wrap_glProgramParameteri
#define glProgramParameteriEXT wrap_glProgramParameteriEXT
#define glProgramPathFragmentInputGenNV wrap_glProgramPathFragmentInputGenNV
#define glProgramUniform1f wrap_glProgramUniform1f
#define glProgramUniform1fEXT wrap_glProgramUniform1fEXT
#define glProgramUniform1fv wrap_glProgramUniform1fv
#define glProgramUniform1fvEXT wrap_glProgramUniform1fvEXT
#define glProgramUniform1i wrap_glProgramUniform1i
#define glProgramUniform1iEXT wrap_glProgramUniform1iEXT
#define glProgramUniform1iv wrap_glProgramUniform1iv
#define glProgramUniform1ivEXT wrap_glProgramUniform1ivEXT
#define glProgramUniform1ui wrap_glProgramUniform1ui
#define glProgramUniform1uiEXT wrap_glProgramUniform1uiEXT
#define glProgramUniform1uiv wrap_glProgramUniform1uiv
#define glProgramUniform1uivEXT wrap_glProgramUniform1uivEXT
#define glProgramUniform2f wrap_glProgramUniform2f
#define glProgramUniform2fEXT wrap_glProgramUniform2fEXT
#define glProgramUniform2fv wrap_glProgramUniform2fv
#define glProgramUniform2fvEXT wrap_glProgramUniform2fvEXT
#define glProgramUniform2i wrap_glProgramUniform2i
#define glProgramUniform2iEXT wrap_glProgramUniform2iEXT
#define glProgramUniform2iv wrap_glProgramUniform2iv
#define glProgramUniform2ivEXT wrap_glProgramUniform2ivEXT
#define glProgramUniform2ui wrap_glProgramUniform2ui
#define glProgramUniform2uiEXT wrap_glProgramUniform2uiEXT
#define glProgramUniform2uiv wrap_glProgramUniform2uiv
#define glProgramUniform2uivEXT wrap_glProgramUniform2uivEXT
#define glProgramUniform3f wrap_glProgramUniform3f
#define glProgramUniform3fEXT wrap_glProgramUniform3fEXT
#define glProgramUniform3fv wrap_glProgramUniform3fv
#define glProgramUniform3fvEXT wrap_glProgramUniform3fvEXT
#define glProgramUniform3i wrap_glProgramUniform3i
#define glProgramUniform3iEXT wrap_glProgramUniform3iEXT
#define glProgramUniform3iv wrap_glProgramUniform3iv
#define glProgramUniform3ivEXT wrap_glProgramUniform3ivEXT
#define glProgramUniform3ui wrap_glProgramUniform3ui
#define glProgramUniform3uiEXT wrap_glProgramUniform3uiEXT
#define glProgramUniform3uiv wrap_glProgramUniform3uiv
#define glProgramUniform3uivEXT wrap_glProgramUniform3uivEXT
#define glProgramUniform4f wrap_glProgramUniform4f
#define glProgramUniform4fEXT wrap_glProgramUniform4fEXT
#define glProgramUniform4fv wrap_glProgramUniform4fv
#define glProgramUniform4fvEXT wrap_glProgramUniform4fvEXT
#define glProgramUniform4i wrap_glProgramUniform4i
#define glProgramUniform4iEXT wrap_glProgramUniform4iEXT
#define glProgramUniform4iv wrap_glProgramUniform4iv
#define glProgramUniform4ivEXT wrap_glProgramUniform4ivEXT
#define glProgramUniform4ui wrap_glProgramUniform4ui
#define glProgramUniform4uiEXT wrap_glProgramUniform4uiEXT
#define glProgramUniform4uiv wrap_glProgramUniform4uiv
#define glProgramUniform4uivEXT wrap_glProgramUniform4uivEXT
#define glProgramUniformHandleui64NV wrap_glProgramUniformHandleui64NV
#define glProgramUniformHandleui64vNV wrap_glProgramUniformHandleui64vNV
#define glProgramUniformMatrix2fv wrap_glProgramUniformMatrix2fv
#define glProgramUniformMatrix2fvEXT wrap_glProgramUniformMatrix2fvEXT
#define glProgramUniformMatrix2x3fv wrap_glProgramUniformMatrix2x3fv
#define glProgramUniformMatrix2x3fvEXT wrap_glProgramUniformMatrix2x3fvEXT
#define glProgramUniformMatrix2x4fv wrap_glProgramUniformMatrix2x4fv
#define glProgramUniformMatrix2x4fvEXT wrap_glProgramUniformMatrix2x4fvEXT
#define glProgramUniformMatrix3fv wrap_glProgramUniformMatrix3fv
#define glProgramUniformMatrix3fvEXT wrap_glProgramUniformMatrix3fvEXT
#define glProgramUniformMatrix3x2fv wrap_glProgramUniformMatrix3x2fv
#define glProgramUniformMatrix3x2fvEXT wrap_glProgramUniformMatrix3x2fvEXT
#define glProgramUniformMatrix3x4fv wrap_glProgramUniformMatrix3x4fv
#define glProgramUniformMatrix3x4fvEXT wrap_glProgramUniformMatrix3x4fvEXT
#define glProgramUniformMatrix4fv wrap_glProgramUniformMatrix4fv
#define glProgramUniformMatrix4fvEXT wrap_glProgramUniformMatrix4fvEXT
#define glProgramUniformMatrix4x2fv wrap_glProgramUniformMatrix4x2fv
#define glProgramUniformMatrix4x2fvEXT wrap_glProgramUniformMatrix4x2fvEXT
#define glProgramUniformMatrix4x3fv wrap_glProgramUniformMatrix4x3fv
#define glProgramUniformMatrix4x3fvEXT wrap_glProgramUniformMatrix4x3fvEXT
#define glPushDebugGroup wrap_glPushDebugGroup
#define glPushDebugGroupKHR wrap_glPushDebugGroupKHR
#define glPushGroupMarkerEXT wrap_glPushGroupMarkerEXT
#define glPushMatrix wrap_glPushMatrix
#define glQueryCounterEXT wrap_glQueryCounterEXT
#define glQueryMatrixxOES wrap_glQueryMatrixxOES
#define glRasterSamplesEXT wrap_glRasterSamplesEXT
#define glReadBuffer wrap_glReadBuffer
#define glReadBufferIndexedEXT wrap_glReadBufferIndexedEXT
#define glReadBufferNV wrap_glReadBufferNV
#define glReadPixels wrap_glReadPixels
#define glReadnPixels wrap_glReadnPixels
#define glReadnPixelsEXT wrap_glReadnPixelsEXT
#define glReadnPixelsKHR wrap_glReadnPixelsKHR
#define glReleaseShaderCompiler wrap_glReleaseShaderCompiler
#define glRenderbufferStorage wrap_glRenderbufferStorage
#define glRenderbufferStorageMultisample wrap_glRenderbufferStorageMultisample
#define glRenderbufferStorageMultisampleANGLE wrap_glRenderbufferStorageMultisampleANGLE
#define glRenderbufferStorageMultisampleAPPLE wrap_glRenderbufferStorageMultisampleAPPLE
#define glRenderbufferStorageMultisampleEXT wrap_glRenderbufferStorageMultisampleEXT
#define glRenderbufferStorageMultisampleIMG wrap_glRenderbufferStorageMultisampleIMG
#define glRenderbufferStorageMultisampleNV wrap_glRenderbufferStorageMultisampleNV
#define glRenderbufferStorageOES wrap_glRenderbufferStorageOES
#define glResolveDepthValuesNV wrap_glResolveDepthValuesNV
#define glResolveMultisampleFramebufferAPPLE wrap_glResolveMultisampleFramebufferAPPLE
#define glResumeTransformFeedback wrap_glResumeTransformFeedback
#define glRotatef wrap_glRotatef
#define glRotatex wrap_glRotatex
#define glRotatexOES wrap_glRotatexOES
#define glSampleCoverage wrap_glSampleCoverage
#define glSampleCoveragex wrap_glSampleCoveragex
#define glSampleCoveragexOES wrap_glSampleCoveragexOES
#define glSampleMaski wrap_glSampleMaski
#define glSamplerParameterIiv wrap_glSamplerParameterIiv
#define glSamplerParameterIivEXT wrap_glSamplerParameterIivEXT
#define glSamplerParameterIivOES wrap_glSamplerParameterIivOES
#define glSamplerParameterIuiv wrap_glSamplerParameterIuiv
#define glSamplerParameterIuivEXT wrap_glSamplerParameterIuivEXT
#define glSamplerParameterIuivOES wrap_glSamplerParameterIuivOES
#define glSamplerParameterf wrap_glSamplerParameterf
#define glSamplerParameterfv wrap_glSamplerParameterfv
#define glSamplerParameteri wrap_glSamplerParameteri
#define glSamplerParameteriv wrap_glSamplerParameteriv
#define glScalef wrap_glScalef
#define glScalex wrap_glScalex
#define glScalexOES wrap_glScalexOES
#define glScissor wrap_glScissor
#define glScissorArrayvNV wrap_glScissorArrayvNV
#define glScissorIndexedNV wrap_glScissorIndexedNV
#define glScissorIndexedvNV wrap_glScissorIndexedvNV
#define glSelectPerfMonitorCountersAMD wrap_glSelectPerfMonitorCountersAMD
#define glSetFenceNV wrap_glSetFenceNV
#define glShadeModel wrap_glShadeModel
#define glShaderBinary wrap_glShaderBinary
#define glShaderSource wrap_glShaderSource
#define glStartTilingQCOM wrap_glStartTilingQCOM
#define glStencilFillPathInstancedNV wrap_glStencilFillPathInstancedNV
#define glStencilFillPathNV wrap_glStencilFillPathNV
#define glStencilFunc wrap_glStencilFunc
#define glStencilFuncSeparate wrap_glStencilFuncSeparate
#define glStencilMask wrap_glStencilMask
#define glStencilMaskSeparate wrap_glStencilMaskSeparate
#define glStencilOp wrap_glStencilOp
#define glStencilOpSeparate wrap_glStencilOpSeparate
#define glStencilStrokePathInstancedNV wrap_glStencilStrokePathInstancedNV
#define glStencilStrokePathNV wrap_glStencilStrokePathNV
#define glStencilThenCoverFillPathInstancedNV wrap_glStencilThenCoverFillPathInstancedNV
#define glStencilThenCoverFillPathNV wrap_glStencilThenCoverFillPathNV
#define glStencilThenCoverStrokePathInstancedNV wrap_glStencilThenCoverStrokePathInstancedNV
#define glStencilThenCoverStrokePathNV wrap_glStencilThenCoverStrokePathNV
#define glSubpixelPrecisionBiasNV wrap_glSubpixelPrecisionBiasNV
#define glTestFenceNV wrap_glTestFenceNV
#define glTexBuffer wrap_glTexBuffer
#define glTexBufferEXT wrap_glTexBufferEXT
#define glTexBufferOES wrap_glTexBufferOES
#define glTexBufferRange wrap_glTexBufferRange
#define glTexBufferRangeEXT wrap_glTexBufferRangeEXT
#define glTexBufferRangeOES wrap_glTexBufferRangeOES
#define glTexCoordPointer wrap_glTexCoordPointer
#define glTexEnvf wrap_glTexEnvf
#define glTexEnvfv wrap_glTexEnvfv
#define glTexEnvi wrap_glTexEnvi
#define glTexEnviv wrap_glTexEnviv
#define glTexEnvx wrap_glTexEnvx
#define glTexEnvxOES wrap_glTexEnvxOES
#define glTexEnvxv wrap_glTexEnvxv
#define glTexEnvxvOES wrap_glTexEnvxvOES
#define glTexGenfOES wrap_glTexGenfOES
#define glTexGenfvOES wrap_glTexGenfvOES
#define glTexGeniOES wrap_glTexGeniOES
#define glTexGenivOES wrap_glTexGenivOES
#define glTexGenxOES wrap_glTexGenxOES
#define glTexGenxvOES wrap_glTexGenxvOES
#define glTexImage2D wrap_glTexImage2D
#define glTexImage3D wrap_glTexImage3D
#define glTexImage3DOES wrap_glTexImage3DOES
#define glTexPageCommitmentEXT wrap_glTexPageCommitmentEXT
#define glTexParameterIiv wrap_glTexParameterIiv
#define glTexParameterIivEXT wrap_glTexParameterIivEXT
#define glTexParameterIivOES wrap_glTexParameterIivOES
#define glTexParameterIuiv wrap_glTexParameterIuiv
#define glTexParameterIuivEXT wrap_glTexParameterIuivEXT
#define glTexParameterIuivOES wrap_glTexParameterIuivOES
#define glTexParameterf wrap_glTexParameterf
#define glTexParameterfv wrap_glTexParameterfv
#define glTexParameteri wrap_glTexParameteri
#define glTexParameteriv wrap_glTexParameteriv
#define glTexParameterx wrap_glTexParameterx
#define glTexParameterxOES wrap_glTexParameterxOES
#define glTexParameterxv wrap_glTexParameterxv
#define glTexParameterxvOES wrap_glTexParameterxvOES
#define glTexStorage1DEXT wrap_glTexStorage1DEXT
#define glTexStorage2D wrap_glTexStorage2D
#define glTexStorage2DEXT wrap_glTexStorage2DEXT
#define glTexStorage2DMultisample wrap_glTexStorage2DMultisample
#define glTexStorage3D wrap_glTexStorage3D
#define glTexStorage3DEXT wrap_glTexStorage3DEXT
#define glTexStorage3DMultisample wrap_glTexStorage3DMultisample
#define glTexStorage3DMultisampleOES wrap_glTexStorage3DMultisampleOES
#define glTexSubImage2D wrap_glTexSubImage2D
#define glTexSubImage3D wrap_glTexSubImage3D
#define glTexSubImage3DOES wrap_glTexSubImage3DOES
#define glTextureStorage1DEXT wrap_glTextureStorage1DEXT
#define glTextureStorage2DEXT wrap_glTextureStorage2DEXT
#define glTextureStorage3DEXT wrap_glTextureStorage3DEXT
#define glTextureViewEXT wrap_glTextureViewEXT
#define glTextureViewOES wrap_glTextureViewOES
#define glTransformFeedbackVaryings wrap_glTransformFeedbackVaryings
#define glTransformPathNV wrap_glTransformPathNV
#define glTranslatef wrap_glTranslatef
#define glTranslatex wrap_glTranslatex
#define glTranslatexOES wrap_glTranslatexOES
#define glUniform1f wrap_glUniform1f
#define glUniform1fv wrap_glUniform1fv
#define glUniform1i wrap_glUniform1i
#define glUniform1iv wrap_glUniform1iv
#define glUniform1ui wrap_glUniform1ui
#define glUniform1uiv wrap_glUniform1uiv
#define glUniform2f wrap_glUniform2f
#define glUniform2fv wrap_glUniform2fv
#define glUniform2i wrap_glUniform2i
#define glUniform2iv wrap_glUniform2iv
#define glUniform2ui wrap_glUniform2ui
#define glUniform2uiv wrap_glUniform2uiv
#define glUniform3f wrap_glUniform3f
#define glUniform3fv wrap_glUniform3fv
#define glUniform3i wrap_glUniform3i
#define glUniform3iv wrap_glUniform3iv
#define glUniform3ui wrap_glUniform3ui
#define glUniform3uiv wrap_glUniform3uiv
#define glUniform4f wrap_glUniform4f
#define glUniform4fv wrap_glUniform4fv
#define glUniform4i wrap_glUniform4i
#define glUniform4iv wrap_glUniform4iv
#define glUniform4ui wrap_glUniform4ui
#define glUniform4uiv wrap_glUniform4uiv
#define glUniformBlockBinding wrap_glUniformBlockBinding
#define glUniformHandleui64NV wrap_glUniformHandleui64NV
#define glUniformHandleui64vNV wrap_glUniformHandleui64vNV
#define glUniformMatrix2fv wrap_glUniformMatrix2fv
#define glUniformMatrix2x3fv wrap_glUniformMatrix2x3fv
#define glUniformMatrix2x3fvNV wrap_glUniformMatrix2x3fvNV
#define glUniformMatrix2x4fv wrap_glUniformMatrix2x4fv
#define glUniformMatrix2x4fvNV wrap_glUniformMatrix2x4fvNV
#define glUniformMatrix3fv wrap_glUniformMatrix3fv
#define glUniformMatrix3x2fv wrap_glUniformMatrix3x2fv
#define glUniformMatrix3x2fvNV wrap_glUniformMatrix3x2fvNV
#define glUniformMatrix3x4fv wrap_glUniformMatrix3x4fv
#define glUniformMatrix3x4fvNV wrap_glUniformMatrix3x4fvNV
#define glUniformMatrix4fv wrap_glUniformMatrix4fv
#define glUniformMatrix4x2fv wrap_glUniformMatrix4x2fv
#define glUniformMatrix4x2fvNV wrap_glUniformMatrix4x2fvNV
#define glUniformMatrix4x3fv wrap_glUniformMatrix4x3fv
#define glUniformMatrix4x3fvNV wrap_glUniformMatrix4x3fvNV
#define glUnmapBuffer wrap_glUnmapBuffer
#define glUnmapBufferOES wrap_glUnmapBufferOES
#define glUseProgram wrap_glUseProgram
#define glUseProgramStages wrap_glUseProgramStages
#define glUseProgramStagesEXT wrap_glUseProgramStagesEXT
#define glValidateProgram wrap_glValidateProgram
#define glValidateProgramPipeline wrap_glValidateProgramPipeline
#define glValidateProgramPipelineEXT wrap_glValidateProgramPipelineEXT
#define glVertexAttrib1f wrap_glVertexAttrib1f
#define glVertexAttrib1fv wrap_glVertexAttrib1fv
#define glVertexAttrib2f wrap_glVertexAttrib2f
#define glVertexAttrib2fv wrap_glVertexAttrib2fv
#define glVertexAttrib3f wrap_glVertexAttrib3f
#define glVertexAttrib3fv wrap_glVertexAttrib3fv
#define glVertexAttrib4f wrap_glVertexAttrib4f
#define glVertexAttrib4fv wrap_glVertexAttrib4fv
#define glVertexAttribBinding wrap_glVertexAttribBinding
#define glVertexAttribDivisor wrap_glVertexAttribDivisor
#define glVertexAttribDivisorANGLE wrap_glVertexAttribDivisorANGLE
#define glVertexAttribDivisorEXT wrap_glVertexAttribDivisorEXT
#define glVertexAttribDivisorNV wrap_glVertexAttribDivisorNV
#define glVertexAttribFormat wrap_glVertexAttribFormat
#define glVertexAttribI4i wrap_glVertexAttribI4i
#define glVertexAttribI4iv wrap_glVertexAttribI4iv
#define glVertexAttribI4ui wrap_glVertexAttribI4ui
#define glVertexAttribI4uiv wrap_glVertexAttribI4uiv
#define glVertexAttribIFormat wrap_glVertexAttribIFormat
#define glVertexAttribIPointer wrap_glVertexAttribIPointer
#define glVertexAttribPointer wrap_glVertexAttribPointer
#define glVertexBindingDivisor wrap_glVertexBindingDivisor
#define glVertexPointer wrap_glVertexPointer
#define glViewport wrap_glViewport
#define glViewportArrayvNV wrap_glViewportArrayvNV
#define glViewportIndexedfNV wrap_glViewportIndexedfNV
#define glViewportIndexedfvNV wrap_glViewportIndexedfvNV
#define glWaitSync wrap_glWaitSync
#define glWaitSyncAPPLE wrap_glWaitSyncAPPLE
#define glWeightPathsNV wrap_glWeightPathsNV
#define glWeightPointerOES wrap_glWeightPointerOES